"""专家Agent模块 - 支持多轮Tool Call和RAG的复杂任务处理"""

from abc import ABC, abstractmethod
from typing import Dict, Any, List
from loguru import logger
from openai import OpenAI
import json

from ..models.schemas import QuestionType, AgentContext, RAGResult, ToolCallResult
from ..utils.prompt_loader import load_expert_prompt


class BaseExpertAgent(ABC):
    """专家Agent基类"""
    
    def __init__(self, openai_client: OpenAI):
        self.client = openai_client
        # 加载系统提示词
        self.system_prompt = self._load_system_prompt()
    
    def _load_system_prompt(self) -> str:
        """
        加载当前Agent的系统提示词
        子类可以重写此方法来指定具体的提示词文件名
        """
        # 根据类名推导提示词文件名
        class_name = self.__class__.__name__
        
        # 将类名转换为文件名格式
        if class_name == "PageNavigationAgent":
            agent_name = "page_navigation_agent"
        elif class_name == "SystemGuideAgent":
            agent_name = "system_guide_agent"
        elif class_name == "ProductionQAAgent":
            agent_name = "production_qa_agent"
        elif class_name == "ChatAgent":
            agent_name = "chat_agent"
        else:
            # 默认转换：将CamelCase转换为snake_case
            import re
            agent_name = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', class_name)
            agent_name = re.sub('([a-z0-9])([A-Z])', r'\1_\2', agent_name).lower()
        
        return load_expert_prompt(agent_name)
    
    def get_system_message(self) -> Dict[str, str]:
        """
        获取系统消息
        
        Returns:
            系统消息字典
        """
        return {"role": "system", "content": self.system_prompt}
    
    async def need_rag(self, user_question: str) -> bool:
        """使用大模型判断是否需要RAG查询"""
        try:
            prompt = f"""
请分析以下用户问题，判断是否需要查询知识库来获取相关信息。

用户问题：{user_question}

判断标准：
- 如果问题涉及系统操作方法、使用指导、功能介绍等需要查询文档的内容，返回true
- 如果问题是简单的数据查询、状态获取、直接操作等，返回false
- 如果问题涉及标准、规范、流程说明等需要参考资料的，返回true

请只返回true或false，不要其他内容。
"""
            
            messages = [
                self.get_system_message(),
                {"role": "user", "content": prompt}
            ]
            
            response = self.client.chat.completions.create(
                model="gpt-3.5-turbo",
                messages=messages,
                temperature=0.1,
                max_tokens=10
            )
            
            result = response.choices[0].message.content.strip().lower()
            return result == "true"
            
        except Exception as e:
            logger.error(f"RAG需求判断失败: {e}")
            # 默认进行RAG查询，确保不遗漏重要信息
            return True
    
    async def need_tool_call(self, user_question: str, context: AgentContext) -> bool:
        """使用大模型判断是否需要工具调用"""
        try:
            available_tools = [
                "page_navigation - 页面跳转导航",
                "database_query - 查询生产数据、设备状态等",
                "report_generation - 生成各类报表",
                "data_analysis - 数据分析和趋势预测",
                "document_generation - 生成业务文档",
                "external_api_call - 调用外部API",
                "rag_search - 搜索知识库",
                "workflow_execution - 执行工作流程"
            ]
            
            prompt = f"""
请分析以下用户问题，判断是否需要调用工具来完成任务。

用户问题：{user_question}
问题类型：{context.question_type.value}

可用工具：
{chr(10).join(available_tools)}

判断标准：
- 如果用户需要查询具体数据、生成报表、执行操作等，需要调用工具
- 如果用户只是询问概念、方法、一般性问题，可能不需要工具
- 如果用户明确要求"查询"、"生成"、"分析"、"跳转"等动作，需要调用工具

请只返回true或false，不要其他内容。
"""
            
            messages = [
                self.get_system_message(),
                {"role": "user", "content": prompt}
            ]
            
            response = self.client.chat.completions.create(
                model="gpt-3.5-turbo", 
                messages=messages,
                temperature=0.1,
                max_tokens=10
            )
            
            result = response.choices[0].message.content.strip().lower()
            return result == "true"
            
        except Exception as e:
            logger.error(f"工具调用需求判断失败: {e}")
            # 根据问题类型提供默认判断
            if context.question_type in [QuestionType.PAGE_NAVIGATION, QuestionType.PRODUCTION_QA]:
                return True
            return False
    
    @abstractmethod
    async def generate_response(self, context: AgentContext) -> str:
        """生成最终回复"""
        pass
    
    async def execute_complex_task(
        self, 
        task_description: str, 
        context: AgentContext,
        tool_service=None,
        rag_service=None
    ) -> Dict[str, Any]:
        """
        执行复杂任务，支持多轮Tool Call和RAG - 参考report_generation.py的模式
        
        Args:
            task_description: 任务描述
            context: Agent上下文
            tool_service: 工具服务
            rag_service: RAG服务
            
        Returns:
            任务执行结果
        """
        logger.info(f"开始执行复杂任务: {task_description}")
        
        if not tool_service:
            return {"error": "工具服务未初始化"}
        
        # 构建任务上下文
        task_context = {
            "user_question": context.user_question,
            "question_type": context.question_type.value,
            "session_id": context.session_id,
            "existing_rag_results": [
                {"content": r.content, "source": r.source, "score": r.relevance_score}
                for r in context.rag_results
            ],
            "existing_tool_results": [
                {"tool": r.tool_name, "result": r.result, "success": r.success}
                for r in context.tool_call_results
            ]
        }
        
        # 执行多轮工具调用
        tool_results = await tool_service.execute_multi_turn_tool_calls(
            task_description, 
            task_context,
            max_turns=10
        )
        
        return {
            "task_description": task_description,
            "tool_results": tool_results,
            "total_tool_calls": len(tool_results),
            "success": all(r.success for r in tool_results)
        }


class PageNavigationAgent(BaseExpertAgent):
    """页面跳转引导Agent - 支持复杂的多步骤导航任务"""
    
    async def generate_response(self, context: AgentContext) -> str:
        """生成页面跳转回复"""
        try:
            # 分析是否是复杂的多步骤导航任务
            user_question = context.user_question.lower()
            
            # 复杂任务关键词
            complex_keywords = ["批量", "多个", "依次", "然后", "接着", "流程", "步骤", "完整操作"]
            is_complex_task = any(keyword in user_question for keyword in complex_keywords)
            
            if is_complex_task:
                return await self._handle_complex_navigation(context)
            else:
                return await self._handle_simple_navigation(context)
                
        except Exception as e:
            logger.error(f"生成页面跳转回复失败: {e}")
            return "抱歉，我暂时无法处理您的页面跳转请求。"
    
    async def _handle_simple_navigation(self, context: AgentContext) -> str:
        """处理简单的页面跳转"""
        rag_info = self._format_rag_results(context.rag_results)
        tool_info = self._format_tool_results(context.tool_call_results)
        
        if context.tool_call_results and context.tool_call_results[0].success:
            result = context.tool_call_results[0].result
            page_path = result.get("page_path", "")
            return f"✅ 已为您跳转到 **{page_path}** 页面\n\n🔍 **页面信息：**\n{rag_info}\n\n📋 **跳转详情：**\n{tool_info}"
        
        return f"根据您的需求，为您找到了相关页面信息：\n\n{rag_info}\n\n{tool_info}"
    
    async def _handle_complex_navigation(self, context: AgentContext) -> str:
        """处理复杂的多步骤导航任务"""
        navigation_steps = []
        
        # 基于工具执行结果构建导航步骤
        for i, tool_result in enumerate(context.tool_call_results, 1):
            if tool_result.success and tool_result.tool_name == "page_navigation":
                result = tool_result.result
                page_path = result.get("page_path", "")
                operation = result.get("operation", "")
                navigation_steps.append(f"**步骤 {i}：** 跳转到 {page_path} - {operation} ✅")
        
        if not navigation_steps:
            return "正在为您规划复杂的导航方案，请稍等..."
        
        response = "🚀 **多步骤导航已完成**\n\n"
        response += "\n".join(navigation_steps)
        
        # 添加RAG信息
        if context.rag_results:
            rag_info = self._format_rag_results(context.rag_results)
            response += f"\n\n📚 **相关指导信息：**\n{rag_info}"
        
        return response
    
    def _format_rag_results(self, rag_results: List[RAGResult]) -> str:
        """格式化RAG结果"""
        if not rag_results:
            return "未找到相关页面信息"
        
        formatted = []
        for i, result in enumerate(rag_results, 1):
            formatted.append(f"{i}. {result.content} (来源: {result.source})")
        return "\n".join(formatted)
    
    def _format_tool_results(self, tool_results: List[ToolCallResult]) -> str:
        """格式化工具调用结果"""
        if not tool_results:
            return "无工具调用执行"
        
        formatted = []
        for result in tool_results:
            if result.success:
                if result.tool_name == "page_navigation":
                    page_path = result.result.get("page_path", "未知")
                    formatted.append(f"✅ 页面跳转: {page_path}")
                else:
                    formatted.append(f"✅ {result.tool_name}: 执行成功")
            else:
                formatted.append(f"❌ {result.tool_name}: {result.error_message}")
        return "\n".join(formatted)


class SystemGuideAgent(BaseExpertAgent):
    """系统使用引导Agent - 支持复杂的操作指导任务"""
    
    async def generate_response(self, context: AgentContext) -> str:
        """生成系统使用指导回复"""
        try:
            user_question = context.user_question.lower()
            
            # 检查是否是复杂操作指导
            if any(keyword in user_question for keyword in ["报表生成", "数据导出", "批量操作", "工作流"]):
                return await self._handle_complex_guidance(context)
            else:
                return await self._handle_simple_guidance(context)
                
        except Exception as e:
            logger.error(f"生成系统指导回复失败: {e}")
            return "抱歉，我暂时无法为您提供系统使用指导。"
    
    async def _handle_simple_guidance(self, context: AgentContext) -> str:
        """处理简单的系统指导"""
        rag_info = self._format_rag_results(context.rag_results)
        
        response = f"📋 **系统使用指导**\n\n{rag_info}"
        
        if context.tool_call_results:
            tool_info = self._format_tool_results(context.tool_call_results)
            response += f"\n\n🔧 **相关工具执行结果：**\n{tool_info}"
        
        return response
    
    async def _handle_complex_guidance(self, context: AgentContext) -> str:
        """处理复杂的操作指导"""
        guidance_steps = []
        
        # 基于RAG结果构建指导步骤
        for i, rag_result in enumerate(context.rag_results, 1):
            guidance_steps.append(f"**步骤 {i}：** {rag_result.content}")
        
        # 基于工具执行结果提供具体操作
        tool_operations = []
        for tool_result in context.tool_call_results:
            if tool_result.success:
                if tool_result.tool_name == "report_generation":
                    result = tool_result.result
                    tool_operations.append(f"📊 **报表生成完成**：{result.get('report_name', '')} - {result.get('status', '')}")
                    if result.get('download_url'):
                        tool_operations.append(f"📥 下载链接：{result.get('download_url')}")
                        
                elif tool_result.tool_name == "document_generation":
                    result = tool_result.result
                    tool_operations.append(f"📄 **文档生成完成**：{result.get('template_name', '')} - {result.get('status', '')}")
                    if result.get('download_url'):
                        tool_operations.append(f"📥 下载链接：{result.get('download_url')}")
                        
                elif tool_result.tool_name == "workflow_execution":
                    result = tool_result.result
                    workflow_name = result.get('workflow_name', '')
                    current_step = result.get('current_step', 0)
                    total_steps = len(result.get('steps', []))
                    tool_operations.append(f"⚙️ **工作流执行**：{workflow_name} ({current_step}/{total_steps})")
        
        response_parts = []
        
        if guidance_steps:
            response_parts.append("📖 **详细操作指导：**\n" + "\n\n".join(guidance_steps))
        
        if tool_operations:
            response_parts.append("🛠️ **实际执行结果：**\n" + "\n".join(tool_operations))
        
        if not response_parts:
            return "正在为您准备详细的操作指导，请稍等..."
        
        return "\n\n".join(response_parts)
    
    def _format_rag_results(self, rag_results: List[RAGResult]) -> str:
        """格式化RAG结果"""
        if not rag_results:
            return "暂未找到相关指导信息"
        
        formatted = []
        for i, result in enumerate(rag_results, 1):
            formatted.append(f"**{i}.** {result.content}")
            if result.source:
                formatted.append(f"   *来源：{result.source}*")
        return "\n".join(formatted)
    
    def _format_tool_results(self, tool_results: List[ToolCallResult]) -> str:
        """格式化工具调用结果"""
        if not tool_results:
            return "无相关操作执行"
        
        formatted = []
        for result in tool_results:
            status = "✅ 成功" if result.success else f"❌ 失败: {result.error_message}"
            formatted.append(f"- **{result.tool_name}**: {status}")
            
            if result.success and result.result:
                # 添加详细信息
                if result.tool_name == "report_generation":
                    formatted.append(f"  📊 {result.result.get('report_name', '')}")
                elif result.tool_name == "document_generation":
                    formatted.append(f"  📄 {result.result.get('template_name', '')}")
                    
        return "\n".join(formatted)


class ProductionQAAgent(BaseExpertAgent):
    """生产QA Agent - 支持复杂的数据查询和分析任务"""
    
    async def generate_response(self, context: AgentContext) -> str:
        """生成生产QA回复"""
        try:
            user_question = context.user_question.lower()
            
            # 检查是否需要复杂分析
            if any(keyword in user_question for keyword in ["分析", "趋势", "对比", "预测", "综合"]):
                return await self._handle_complex_analysis(context)
            else:
                return await self._handle_simple_query(context)
                
        except Exception as e:
            logger.error(f"生成生产QA回复失败: {e}")
            return "抱歉，我暂时无法查询到相关生产信息。"
    
    async def _handle_simple_query(self, context: AgentContext) -> str:
        """处理简单的数据查询"""
        response_parts = []
        
        # 格式化工具调用结果
        for tool_result in context.tool_call_results:
            if tool_result.success:
                if tool_result.tool_name == "database_query":
                    response_parts.append(self._format_query_result(tool_result.result))
                elif tool_result.tool_name == "data_analysis":
                    response_parts.append(self._format_analysis_result(tool_result.result))
        
        # 添加RAG信息
        if context.rag_results:
            rag_info = "\n".join([f"📚 {r.content}" for r in context.rag_results])
            response_parts.append(f"**相关标准和规范：**\n{rag_info}")
        
        return "\n\n".join(response_parts) if response_parts else "暂无相关数据"
    
    async def _handle_complex_analysis(self, context: AgentContext) -> str:
        """处理复杂的数据分析"""
        analysis_results = []
        
        for tool_result in context.tool_call_results:
            if tool_result.success:
                if tool_result.tool_name == "data_analysis":
                    result = tool_result.result
                    analysis_results.append(f"""
📊 **{result.get('analysis_name', '数据分析')}**
- 数据源：{result.get('data_source', '未知')}
- 分析时间：{result.get('analysis_time', '未知')}
- 主要发现：{result.get('trend', result.get('current_efficiency', '无'))}
- 置信度：{result.get('confidence', 'N/A')}
""")
                elif tool_result.tool_name == "database_query":
                    analysis_results.append(self._format_detailed_query_result(tool_result.result))
        
        if not analysis_results:
            return "正在进行复杂数据分析，请稍等片刻..."
        
        return "基于您的需求，我为您提供以下详细分析：\n\n" + "\n".join(analysis_results)
    
    def _format_query_result(self, result: Dict[str, Any]) -> str:
        """格式化查询结果"""
        if "total_orders" in result:
            efficiency_icon = "🟢" if result.get('efficiency', 0) >= 85 else "🟡" if result.get('efficiency', 0) >= 70 else "🔴"
            return f"""
📈 **生产状态概览**
- 总订单数：{result.get('total_orders', 0)}
- 已完成：{result.get('completed_orders', 0)} ✅
- 进行中：{result.get('in_progress_orders', 0)} 🔄  
- 待处理：{result.get('pending_orders', 0)} ⏳
- 生产效率：{result.get('efficiency', 0)}% {efficiency_icon}
"""
        elif "total_materials" in result:
            stock_status = "🟢 正常" if result.get('out_of_stock_materials', 0) == 0 else "🔴 需关注"
            return f"""
📦 **物料库存状态** {stock_status}
- 物料总数：{result.get('total_materials', 0)}
- 低库存：{result.get('low_stock_materials', 0)}项 ⚠️
- 缺货：{result.get('out_of_stock_materials', 0)}项 🚫
"""
        elif "total_equipment" in result:
            equipment_health = "🟢 良好" if result.get('fault', 0) <= 2 else "🟡 一般" if result.get('fault', 0) <= 5 else "🔴 需维护"
            return f"""
🔧 **设备运行状态** {equipment_health}
- 设备总数：{result.get('total_equipment', 0)}
- 运行中：{result.get('running', 0)} ✅
- 维护中：{result.get('maintenance', 0)} 🔧
- 故障：{result.get('fault', 0)} ⚠️
"""
        
        return f"查询结果：{json.dumps(result, ensure_ascii=False, indent=2)}"
    
    def _format_detailed_query_result(self, result: Dict[str, Any]) -> str:
        """格式化详细查询结果"""
        formatted_parts = []
        
        if "daily_output" in result:
            output_data = result["daily_output"]
            formatted_parts.append("📊 **近期产量趋势**")
            for item in output_data[-3:]:  # 显示最近3天
                efficiency = item.get('efficiency', 0)
                trend_icon = "📈" if efficiency > 100 else "📊" if efficiency >= 90 else "📉"
                formatted_parts.append(f"- {item.get('date', '')}: {item.get('output', 0)}件 (效率: {efficiency}%) {trend_icon}")
        
        if "fault_list" in result:
            fault_data = result["fault_list"]
            formatted_parts.append("\n⚠️ **设备故障详情**")
            for fault in fault_data:
                level = fault.get('level', '一般')
                level_icon = "🔴" if level == "严重" else "🟡" if level == "中等" else "🟢"
                formatted_parts.append(f"- {fault.get('equipment_id', '')}: {fault.get('fault', '')} {level_icon}")
        
        if "pending_orders" in result:
            orders = result["pending_orders"]
            formatted_parts.append("\n📋 **待处理订单**")
            for order in orders[-5:]:  # 显示最近5个
                priority_icon = "🔴" if order.get('priority') == "高" else "🟡" if order.get('priority') == "中" else "🟢"
                formatted_parts.append(f"- {order.get('order_id', '')}: {order.get('customer', '')} - {order.get('quantity', 0)}件 {priority_icon}")
        
        return "\n".join(formatted_parts) if formatted_parts else self._format_query_result(result)
    
    def _format_analysis_result(self, result: Dict[str, Any]) -> str:
        """格式化分析结果"""
        if "trend" in result:
            trend_icon = "📈" if result.get('trend') == "上升" else "📉" if result.get('trend') == "下降" else "📊"
            confidence = result.get('confidence', 0) * 100
            return f"""
📈 **趋势分析结果** {trend_icon}
- 趋势方向：{result.get('trend', '未知')}
- 增长率：{result.get('growth_rate', 0)}%
- 预测：{result.get('prediction', '无')}
- 置信度：{confidence:.1f}%
"""
        elif "current_efficiency" in result:
            improvement = result.get('improvement', 0)
            improvement_icon = "📈" if improvement > 0 else "📉" if improvement < 0 else "📊"
            return f"""
⚡ **效率分析结果** {improvement_icon}
- 当前效率：{result.get('current_efficiency', 0)}%
- 基准效率：{result.get('baseline_efficiency', 0)}%
- 改善幅度：{improvement}%
- 改善建议：{', '.join(result.get('recommendations', []))}
"""
        
        return f"分析结果：{json.dumps(result, ensure_ascii=False, indent=2)}"


class ChatAgent(BaseExpertAgent):
    """闲聊Agent - 支持智能对话和辅助功能"""
    
    async def generate_response(self, context: AgentContext) -> str:
        """生成闲聊回复"""
        try:
            user_question = context.user_question.lower()
            
            # 系统介绍类问题
            if any(keyword in user_question for keyword in ["你是谁", "功能", "能力", "介绍"]):
                return self._handle_system_introduction(context)
            
            # 帮助类问题
            elif any(keyword in user_question for keyword in ["帮助", "怎么用", "如何使用"]):
                return self._handle_help_request(context)
            
            # 其他闲聊
            else:
                return self._handle_general_chat(context)
                
        except Exception as e:
            logger.error(f"生成闲聊回复失败: {e}")
            return "很高兴与您聊天！有什么我可以帮助您的吗？ 😊"
    
    def _handle_system_introduction(self, context: AgentContext) -> str:
        """处理系统介绍"""
        intro = """
👋 **您好！我是MES系统的AI智能助手**

✨ **核心能力：**
🔹 **页面跳转引导** - 智能导航，快速找到目标功能页面
🔹 **系统使用指导** - 详细操作说明和最佳实践指导
🔹 **生产数据查询** - 实时查询生产状态、设备信息、物料库存
🔹 **智能数据分析** - 趋势分析、效率分析、质量分析
🔹 **报表文档生成** - 自动生成各类生产报表和业务文档
🔹 **多轮复杂对话** - 支持复杂任务的分步执行和引导

🚀 **高级特性：**
- 🤖 支持多轮工具调用，处理复杂业务流程
- 📚 基于知识库的智能问答
- ⚙️ 工作流自动化执行
- 🔄 上下文感知的连续对话

💡 **使用建议**：
- 用自然语言描述需求，我会智能理解并提供帮助
- 支持复杂任务分解，逐步引导完成操作
- 遇到问题随时询问，基于知识库为您答疑解惑
"""
        
        # 如果有RAG结果，添加相关信息
        if context.rag_results:
            intro += "\n\n📚 **相关系统信息**：\n"
            for i, result in enumerate(context.rag_results[:3], 1):
                intro += f"{i}. {result.content}\n"
        
        return intro
    
    def _handle_help_request(self, context: AgentContext) -> str:
        """处理帮助请求"""
        help_text = """
🔧 **MES AI助手使用指南**

**🎯 基础功能示例：**
- *"帮我跳转到物料入库页面"* → 🔄 页面导航
- *"如何创建生产计划？"* → 📖 操作指导  
- *"查询今天的生产状态"* → 📊 数据查询
- *"生成本月生产报表"* → 📋 报表生成

**🚀 高级功能示例：**
- *"分析最近一周的生产效率趋势"* → 📈 数据分析
- *"批量导入物料信息的完整流程"* → 🔄 复杂任务指导
- *"对比上月和本月的设备故障率"* → 📊 多维度分析
- *"执行质量检验工作流程"* → ⚙️ 工作流执行

**💡 提问技巧：**
✅ **描述具体需求**："我需要查看车间1的设备运行状态"
✅ **提供操作上下文**："在生产计划页面，如何修改订单优先级？"
✅ **明确期望结果**："帮我生成适合向领导汇报的生产月报"

**🔧 可用工具：**
- 📊 数据库查询 - 实时生产数据
- 📈 数据分析 - 趋势预测分析  
- 📋 报表生成 - 多格式输出
- 📄 文档生成 - 业务单据模板
- 🔄 工作流执行 - 自动化流程
- 🔍 知识库搜索 - 智能问答

有任何具体问题，随时问我！我会为您提供最专业的帮助 😊
"""
        
        # 如果有工具执行记录，展示相关功能
        if context.tool_call_results:
            help_text += "\n\n🔍 **您刚刚使用的功能：**\n"
            for result in context.tool_call_results:
                if result.success:
                    tool_emoji = {
                        "database_query": "📊",
                        "report_generation": "📋", 
                        "data_analysis": "📈",
                        "page_navigation": "🔄",
                        "document_generation": "📄"
                    }.get(result.tool_name, "🔧")
                    help_text += f"{tool_emoji} {result.tool_name}\n"
        
        return help_text
    
    def _handle_general_chat(self, context: AgentContext) -> str:
        """处理一般闲聊"""
        user_question = context.user_question.lower()
        
        # 问候语
        if any(greeting in user_question for greeting in ["你好", "hello", "hi", "早上好", "下午好", "晚上好"]):
            return "您好！😊 很高兴为您服务！我是您的专属MES系统AI助手。\n\n💼 **今天我可以帮您：**\n- 查询生产数据和设备状态\n- 生成各类报表和文档\n- 提供系统操作指导\n- 执行复杂的业务流程\n\n有什么需要协助的吗？"
        
        # 感谢语
        elif any(thanks in user_question for thanks in ["谢谢", "感谢", "thanks", "thank you"]):
            return "不客气！😊 很高兴能帮助到您！\n\n🌟 **我随时为您提供：**\n- 专业的MES系统支持\n- 智能的数据分析\n- 高效的任务执行\n\n如果还有其他问题，随时可以问我哦！"
        
        # 道别语
        elif any(goodbye in user_question for goodbye in ["再见", "拜拜", "bye", "goodbye"]):
            return "再见！👋 期待下次为您服务！\n\n📝 **温馨提示：**\n- 您的对话记录已保存\n- 随时可以继续我们的对话\n- 有任何MES系统问题都可以找我\n\n祝您工作顺利！ 🚀"
        
        # 其他闲聊
        else:
            response = "我理解您的想法！😊 作为MES系统的专业AI助手，我更擅长帮助您处理生产管理相关的问题。"
            
            # 如果有RAG结果，尝试给出相关建议
            if context.rag_results:
                response += "\n\n🔍 **基于系统知识库，我找到了相关信息：**\n"
                for i, result in enumerate(context.rag_results[:2], 1):
                    response += f"{i}. {result.content}\n"
            
            response += "\n\n💡 **建议您试试询问：**\n- 🏭 生产数据查询和分析\n- ⚙️ 设备状态和维护信息\n- 📋 报表生成和文档创建\n- 🔄 系统操作指导和流程执行"
            
            # 如果有工具调用结果，展示能力
            if context.tool_call_results:
                response += "\n\n🛠️ **刚刚为您执行的功能展示了我的能力，期待为您处理更多任务！**"
            
            return response


class ExpertAgentFactory:
    """专家Agent工厂类"""
    
    @staticmethod
    def create_agent(question_type: QuestionType, openai_client: OpenAI) -> BaseExpertAgent:
        """
        根据问题类型创建对应的专家Agent
        
        Args:
            question_type: 问题类型
            openai_client: OpenAI客户端
            
        Returns:
            专家Agent实例
        """
        agent_mapping = {
            QuestionType.PAGE_NAVIGATION: PageNavigationAgent,
            QuestionType.SYSTEM_GUIDE: SystemGuideAgent,
            QuestionType.PRODUCTION_QA: ProductionQAAgent,
            QuestionType.CHAT: ChatAgent,
        }
        
        agent_class = agent_mapping.get(question_type, ChatAgent)
        return agent_class(openai_client)
    
    @staticmethod
    def get_available_agents() -> List[str]:
        """获取可用的Agent类型"""
        return [
            "PageNavigationAgent - 页面跳转引导，支持复杂多步骤导航",
            "SystemGuideAgent - 系统使用指导，支持复杂操作流程", 
            "ProductionQAAgent - 生产数据查询分析，支持复杂数据处理",
            "ChatAgent - 智能对话和辅助功能，支持系统介绍和帮助"
        ] 