"""问题编排Agent - 负责分类用户问题"""

import json
from typing import Dict, Any
from loguru import logger
from openai import OpenAI

from ..models.schemas import QuestionType


class QuestionOrchestratorAgent:
    """问题编排Agent，判断用户问题属于哪类问题"""
    
    def __init__(self, openai_client: OpenAI):
        self.client = openai_client
        self.classification_prompt = """
你是一个MES系统的智能助手，负责对用户问题进行分类。

请将用户的问题分类为以下四种类型之一：
1. page_navigation（页面跳转引导）：用户想要执行某个操作，如进出库物料等，需要跳转到相应页面
2. system_guide（系统使用引导）：用户想知道如何使用MES系统的某个功能
3. production_qa（生产QA）：用户想了解公司生产情况、生产数据等
4. chat（闲聊）：不属于以上三类的问题，包括日常闲聊、问候等

请分析用户问题，并严格按照以下JSON格式返回，不要添加任何其他内容：

{{
    "question_type": "page_navigation",
    "confidence": 0.95,
    "reasoning": "用户想要执行物料入库操作，需要跳转到相应页面"
}}

question_type必须是以下之一：page_navigation, system_guide, production_qa, chat

用户问题：{user_question}

请直接返回JSON格式的分类结果："""
    
    async def classify_question(self, user_question: str) -> Dict[str, Any]:
        """
        对用户问题进行分类
        
        Args:
            user_question: 用户输入的问题
            
        Returns:
            分类结果字典
        """
        try:
            logger.info(f"开始分类用户问题: {user_question}")
            
            response = self.client.chat.completions.create(
                model="gpt-3.5-turbo",
                messages=[
                    {
                        "role": "user",
                        "content": self.classification_prompt.format(user_question=user_question)
                    }
                ],
                temperature=0.1,
                max_tokens=200
            )
            
            content = response.choices[0].message.content.strip()
            logger.debug(f"LLM原始响应: {repr(content)}")
            
            # 尝试解析JSON响应，增加更好的错误处理
            result = self._parse_classification_response(content)
            
            # 验证分类结果
            question_type = result.get("question_type")
            if question_type not in [qt.value for qt in QuestionType]:
                logger.warning(f"无效的问题类型: {question_type}，设置为闲聊")
                question_type = QuestionType.CHAT.value
            
            classification_result = {
                "question_type": QuestionType(question_type),
                "confidence": result.get("confidence", 0.5),
                "reasoning": result.get("reasoning", "")
            }
            
            logger.info(f"问题分类完成: {classification_result}")
            return classification_result
            
        except Exception as e:
            logger.error(f"问题分类失败: {e}")
            return {
                "question_type": QuestionType.CHAT,
                "confidence": 0.0,
                "reasoning": f"分类过程出错: {str(e)}"
            }
    
    def _parse_classification_response(self, content: str) -> Dict[str, Any]:
        """
        解析分类响应，增强容错性
        
        Args:
            content: LLM响应内容
            
        Returns:
            解析后的结果字典
        """
        try:
            # 尝试直接解析JSON
            return json.loads(content)
        except json.JSONDecodeError:
            logger.warning(f"直接JSON解析失败，尝试清理内容: {repr(content)}")
            
            # 尝试提取JSON部分
            try:
                # 查找JSON开始和结束标记
                start_idx = content.find('{')
                end_idx = content.rfind('}')
                
                if start_idx != -1 and end_idx != -1 and end_idx > start_idx:
                    json_content = content[start_idx:end_idx + 1]
                    logger.debug(f"提取的JSON内容: {json_content}")
                    return json.loads(json_content)
                    
            except json.JSONDecodeError as e:
                logger.warning(f"提取JSON解析也失败: {e}")
            
            # 如果还是失败，尝试从内容中推断分类
            return self._fallback_classification(content)
    
    def _fallback_classification(self, content: str) -> Dict[str, Any]:
        """
        当JSON解析失败时的后备分类方法
        
        Args:
            content: LLM响应内容
            
        Returns:
            后备分类结果
        """
        content_lower = content.lower()
        
        # 尝试从文本中推断类型
        if "page_navigation" in content_lower:
            question_type = "page_navigation"
        elif "system_guide" in content_lower:
            question_type = "system_guide"
        elif "production_qa" in content_lower:
            question_type = "production_qa"
        elif "chat" in content_lower:
            question_type = "chat"
        else:
            # 根据关键词进行简单分类
            if any(keyword in content_lower for keyword in ["跳转", "页面", "操作", "入库", "出库"]):
                question_type = "page_navigation"
            elif any(keyword in content_lower for keyword in ["如何", "怎么", "使用", "指导", "帮助"]):
                question_type = "system_guide"
            elif any(keyword in content_lower for keyword in ["生产", "产量", "效率", "设备", "订单"]):
                question_type = "production_qa"
            else:
                question_type = "chat"
        
        logger.info(f"后备分类结果: {question_type}")
        
        return {
            "question_type": question_type,
            "confidence": 0.3,  # 较低的置信度
            "reasoning": f"JSON解析失败，基于关键词推断为 {question_type}"
        } 