"""总结Agent - 负责美化最终答案"""

from typing import Dict, Any
from loguru import logger
from openai import OpenAI

from ..models.schemas import QuestionType


class SummaryAgent:
    """总结Agent，对答案进行最终美化"""
    
    def __init__(self, openai_client: OpenAI):
        self.client = openai_client
        self.summary_prompt = """
你是一个专业的内容编辑助手，负责优化AI助手的回复内容。

请根据以下信息对回复进行美化：
1. 保持回复的准确性和完整性
2. 使用友好、专业的语调
3. 确保回复结构清晰、易读
4. 适当添加表情符号或格式化增强可读性
5. 根据问题类型调整回复风格

用户问题：{user_question}
问题类型：{question_type}
专家回复：{expert_response}

请生成一个优化后的最终回复：
        """
    
    async def summarize_and_beautify(
        self, 
        user_question: str, 
        question_type: QuestionType, 
        expert_response: str
    ) -> str:
        """
        对专家Agent的回复进行美化和总结
        
        Args:
            user_question: 用户原始问题
            question_type: 问题类型
            expert_response: 专家Agent的回复
            
        Returns:
            美化后的最终回复
        """
        try:
            logger.info(f"开始美化回复，问题类型: {question_type}")
            
            # 根据问题类型调整prompt
            type_specific_instructions = self._get_type_specific_instructions(question_type)
            
            prompt = self.summary_prompt.format(
                user_question=user_question,
                question_type=question_type.value,
                expert_response=expert_response
            ) + f"\n\n特殊要求：{type_specific_instructions}"
            
            response = self.client.chat.completions.create(
                model="gpt-3.5-turbo",
                messages=[
                    {
                        "role": "user",
                        "content": prompt
                    }
                ],
                temperature=0.7,
                max_tokens=600
            )
            
            beautified_response = response.choices[0].message.content.strip()
            
            logger.info("回复美化完成")
            return beautified_response
            
        except Exception as e:
            logger.error(f"美化回复失败: {e}")
            # 如果美化失败，返回原始回复
            return expert_response
    
    def _get_type_specific_instructions(self, question_type: QuestionType) -> str:
        """根据问题类型获取特殊的美化指令"""
        instructions = {
            QuestionType.PAGE_NAVIGATION: (
                "对于页面跳转引导，请使用清晰的步骤格式，"
                "突出关键操作按钮或链接，使用适当的emoji增强可读性。"
            ),
            QuestionType.SYSTEM_GUIDE: (
                "对于系统使用引导，请使用编号列表格式，"
                "确保每个步骤都简洁明了，可以添加一些提示和注意事项。"
            ),
            QuestionType.PRODUCTION_QA: (
                "对于生产数据回复，请保持专业性，"
                "突出关键数据和趋势，可以使用表格或列表格式展示数据。"
            ),
            QuestionType.CHAT: (
                "对于闲聊回复，请保持友好自然的语调，"
                "可以适当使用emoji，同时可以引导用户了解系统功能。"
            )
        }
        
        return instructions.get(question_type, "请保持友好专业的语调。") 