"""API路由模块"""

from fastapi import APIRouter, HTTPException, Depends
from loguru import logger
from typing import Dict, Any

from ..models.schemas import ChatRequest, ChatResponse
from ..services.ai_service import AIService
from ..utils.config import settings, get_database_config, get_external_api_config

# 创建路由器
router = APIRouter()

# 全局AI服务实例
ai_service = None


async def get_ai_service() -> AIService:
    """获取AI服务实例"""
    global ai_service
    if ai_service is None:
        ai_service = AIService(
            openai_api_key=settings.openai_api_key,
            database_config=get_database_config(),
            api_config=get_external_api_config(),
            knowledge_base_path=settings.knowledge_base_path
        )
        await ai_service.initialize()
    return ai_service


@router.post("/chat", response_model=ChatResponse)
async def chat(
    request: ChatRequest,
    ai_service: AIService = Depends(get_ai_service)
) -> ChatResponse:
    """
    聊天接口
    
    处理用户的聊天请求，支持四种类型的AI功能：
    - 页面跳转引导
    - 系统使用引导  
    - 生产QA
    - 闲聊
    """
    try:
        logger.info(f"收到聊天请求: {request.message}")
        
        # 验证请求
        if not request.message or not request.message.strip():
            raise HTTPException(status_code=400, detail="消息内容不能为空")
        
        if len(request.message) > 1000:
            raise HTTPException(status_code=400, detail="消息内容过长，请控制在1000字符以内")
        
        # 处理聊天请求
        response = await ai_service.chat(request)
        
        logger.info(f"聊天请求处理完成，问题类型: {response.question_type}")
        return response
        
    except HTTPException:
        raise
    except Exception as e:
        logger.error(f"聊天接口处理失败: {e}")
        raise HTTPException(status_code=500, detail="服务器内部错误，请稍后再试")


@router.get("/chat/history/{session_id}")
async def get_chat_history(
    session_id: str,
    ai_service: AIService = Depends(get_ai_service)
) -> Dict[str, Any]:
    """
    获取聊天历史
    
    Args:
        session_id: 会话ID
        
    Returns:
        聊天历史记录
    """
    try:
        logger.info(f"获取聊天历史，会话ID: {session_id}")
        
        if not session_id or not session_id.strip():
            raise HTTPException(status_code=400, detail="会话ID不能为空")
        
        history = ai_service.get_session_history(session_id)
        
        return {
            "session_id": session_id,
            "history": history.get("messages", []),
            "message_count": len(history.get("messages", [])),
            "created_at": history.get("created_at"),
            "last_activity": history.get("last_activity")
        }
        
    except HTTPException:
        raise
    except Exception as e:
        logger.error(f"获取聊天历史失败: {e}")
        raise HTTPException(status_code=500, detail="服务器内部错误，请稍后再试")


@router.get("/health")
async def health_check() -> Dict[str, Any]:
    """
    健康检查接口
    
    Returns:
        服务状态信息
    """
    try:
        return {
            "status": "healthy",
            "service": settings.app_name,
            "version": settings.app_version,
            "message": "MES AI服务运行正常"
        }
    except Exception as e:
        logger.error(f"健康检查失败: {e}")
        raise HTTPException(status_code=503, detail="服务不可用")


@router.get("/info")
async def service_info() -> Dict[str, Any]:
    """
    服务信息接口
    
    Returns:
        服务详细信息
    """
    try:
        return {
            "service_name": settings.app_name,
            "version": settings.app_version,
            "description": "MES系统首页AI后端服务",
            "features": [
                "页面跳转引导",
                "系统使用引导",
                "生产QA",
                "闲聊功能"
            ],
            "supported_question_types": [
                "page_navigation",
                "system_guide", 
                "production_qa",
                "chat"
            ],
            "api_endpoints": [
                "/chat - 聊天接口",
                "/chat/history/{session_id} - 获取聊天历史",
                "/health - 健康检查",
                "/info - 服务信息"
            ]
        }
    except Exception as e:
        logger.error(f"获取服务信息失败: {e}")
        raise HTTPException(status_code=500, detail="服务器内部错误，请稍后再试") 