"""FastAPI应用主文件"""

from fastapi import FastAPI, Request
from fastapi.middleware.cors import CORSMiddleware
from fastapi.responses import JSONResponse
from contextlib import asynccontextmanager
import uvicorn
from loguru import logger
import sys
import os

from .utils.config import settings
from .api.routes import router


def setup_logger():
    """配置日志"""
    # 移除默认的logger
    logger.remove()
    
    # 配置控制台输出
    logger.add(
        sys.stderr,
        level=settings.log_level,
        format="<green>{time:YYYY-MM-DD HH:mm:ss}</green> | <level>{level: <8}</level> | <cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>",
        colorize=True
    )
    
    # 如果配置了日志文件，添加文件输出
    if settings.log_file:
        logger.add(
            settings.log_file,
            level=settings.log_level,
            format="{time:YYYY-MM-DD HH:mm:ss} | {level: <8} | {name}:{function}:{line} - {message}",
            rotation=settings.log_rotation,
            retention=settings.log_retention,
            compression="zip"
        )


@asynccontextmanager
async def lifespan(app: FastAPI):
    """应用生命周期管理"""
    # 启动时的初始化
    logger.info("启动MES AI服务...")
    
    # 创建必要的目录
    os.makedirs(settings.knowledge_base_path, exist_ok=True)
    os.makedirs("logs", exist_ok=True)
    
    logger.info("MES AI服务启动完成")
    yield
    
    # 关闭时的清理
    logger.info("MES AI服务正在关闭...")


def create_app() -> FastAPI:
    """创建FastAPI应用"""
    
    # 设置日志
    setup_logger()
    
    # 创建FastAPI实例
    app = FastAPI(
        title=settings.app_name,
        version=settings.app_version,
        description="MES系统首页AI后端服务，提供智能对话功能",
        docs_url="/docs" if settings.debug else None,
        redoc_url="/redoc" if settings.debug else None,
        lifespan=lifespan
    )
    
    # 添加CORS中间件
    app.add_middleware(
        CORSMiddleware,
        allow_origins=settings.cors_origins,
        allow_credentials=True,
        allow_methods=["*"],
        allow_headers=["*"],
    )
    
    # 注册路由
    app.include_router(router, prefix=settings.api_prefix, tags=["AI Chat"])
    
    # 全局异常处理
    @app.exception_handler(Exception)
    async def global_exception_handler(request: Request, exc: Exception):
        logger.error(f"全局异常处理: {type(exc).__name__}: {str(exc)}")
        return JSONResponse(
            status_code=500,
            content={
                "detail": "服务器内部错误",
                "message": "请稍后再试或联系管理员",
                "error_type": type(exc).__name__ if settings.debug else "InternalServerError"
            }
        )
    
    # 根路径
    @app.get("/")
    async def root():
        return {
            "message": f"欢迎使用{settings.app_name}",
            "version": settings.app_version,
            "status": "running",
            "docs_url": "/docs" if settings.debug else "文档已禁用",
            "api_prefix": settings.api_prefix
        }
    
    return app


# 创建应用实例
app = create_app()


def main():
    """启动服务"""
    logger.info(f"启动{settings.app_name} v{settings.app_version}")
    logger.info(f"服务器配置: {settings.host}:{settings.port}")
    logger.info(f"调试模式: {settings.debug}")
    logger.info(f"API前缀: {settings.api_prefix}")
    
    uvicorn.run(
        "src.app:app",
        host=settings.host,
        port=settings.port,
        reload=settings.debug,
        workers=settings.workers if not settings.debug else 1,
        log_level=settings.log_level.lower(),
        access_log=settings.debug
    )


if __name__ == "__main__":
    main() 