"""API数据模型定义"""

from enum import Enum
from typing import Optional, Dict, Any, List
from pydantic import BaseModel, Field


class QuestionType(str, Enum):
    """问题类型枚举"""
    PAGE_NAVIGATION = "page_navigation"  # 页面跳转引导
    SYSTEM_GUIDE = "system_guide"        # 系统使用引导
    PRODUCTION_QA = "production_qa"      # 生产QA
    CHAT = "chat"                        # 闲聊


class ChatRequest(BaseModel):
    """聊天请求模型"""
    message: str = Field(..., description="用户输入的消息")
    session_id: Optional[str] = Field(None, description="会话ID")
    context: Optional[Dict[str, Any]] = Field(default_factory=dict, description="上下文信息")


class ChatResponse(BaseModel):
    """聊天响应模型"""
    message: str = Field(..., description="AI回复的消息")
    question_type: QuestionType = Field(..., description="问题类型")
    session_id: str = Field(..., description="会话ID")
    need_rag: bool = Field(default=False, description="是否需要RAG")
    need_tool_call: bool = Field(default=False, description="是否需要工具调用")
    metadata: Optional[Dict[str, Any]] = Field(default_factory=dict, description="元数据")


class RAGResult(BaseModel):
    """RAG查询结果模型"""
    content: str = Field(..., description="检索到的内容")
    source: str = Field(..., description="来源")
    relevance_score: float = Field(..., description="相关性分数")


class ToolCallResult(BaseModel):
    """工具调用结果模型"""
    tool_name: str = Field(..., description="工具名称")
    result: Any = Field(..., description="执行结果")
    success: bool = Field(..., description="是否成功")
    error_message: Optional[str] = Field(None, description="错误信息")


class AgentContext(BaseModel):
    """Agent上下文模型"""
    user_question: str = Field(..., description="用户问题")
    question_type: QuestionType = Field(..., description="问题类型")
    rag_results: List[RAGResult] = Field(default_factory=list, description="RAG查询结果")
    tool_call_results: List[ToolCallResult] = Field(default_factory=list, description="工具调用结果")
    session_id: str = Field(..., description="会话ID")
    metadata: Dict[str, Any] = Field(default_factory=dict, description="元数据") 