"""RAG服务模块 - 负责知识库管理和查询"""

import os
from typing import List, Dict, Any
from loguru import logger
import chromadb
from langchain.text_splitter import RecursiveCharacterTextSplitter
from langchain_openai import OpenAIEmbeddings
import httpx
from ..models.schemas import RAGResult


class RAGService:
    """RAG服务类"""
    
    def __init__(self, openai_api_key: str, knowledge_base_path: str = "knowledge_base"):
        self.embeddings = OpenAIEmbeddings(
            openai_api_key=openai_api_key,
            http_client=httpx.Client(
                proxy="socks5://socksuser:8uhb9ijn@35.236.151.13:1080"
            )
        )
        self.knowledge_base_path = knowledge_base_path
        self.chroma_client = chromadb.PersistentClient(path=f"{knowledge_base_path}/chroma_db")
        self.text_splitter = RecursiveCharacterTextSplitter(
            chunk_size=1000,
            chunk_overlap=200,
            length_function=len,
        )
        
        # 初始化向量数据库集合
        self.collections = {
            "system_guide": self._get_or_create_collection("system_guide"),
            "production_data": self._get_or_create_collection("production_data"),
            "page_navigation": self._get_or_create_collection("page_navigation"),
        }
    
    def _get_or_create_collection(self, collection_name: str):
        """获取或创建向量数据库集合"""
        try:
            return self.chroma_client.get_collection(collection_name)
        except Exception:
            return self.chroma_client.create_collection(collection_name)
    
    async def add_documents(self, documents: List[Dict[str, Any]], collection_name: str):
        """
        向知识库添加文档
        
        Args:
            documents: 文档列表，每个文档包含content和metadata
            collection_name: 集合名称
        """
        try:
            logger.info(f"向集合 {collection_name} 添加 {len(documents)} 个文档")
            
            collection = self.collections.get(collection_name)
            if not collection:
                logger.error(f"集合 {collection_name} 不存在")
                return
            
            # 分块处理文档
            texts = []
            metadatas = []
            ids = []
            
            for i, doc in enumerate(documents):
                content = doc.get("content", "")
                metadata = doc.get("metadata", {})
                
                # 分割文档
                chunks = self.text_splitter.split_text(content)
                
                for j, chunk in enumerate(chunks):
                    texts.append(chunk)
                    metadatas.append({
                        **metadata,
                        "chunk_id": f"{i}_{j}",
                        "source": metadata.get("source", "unknown")
                    })
                    ids.append(f"{collection_name}_{i}_{j}")
            
            # 生成embeddings
            embeddings = await self._generate_embeddings(texts)
            
            # 添加到向量数据库
            collection.add(
                embeddings=embeddings,
                documents=texts,
                metadatas=metadatas,
                ids=ids
            )
            
            logger.info(f"成功添加 {len(texts)} 个文档块")
            
        except Exception as e:
            logger.error(f"添加文档失败: {e}")
    
    async def query(self, query_text: str, collection_name: str, top_k: int = 3) -> List[RAGResult]:
        """
        查询知识库
        
        Args:
            query_text: 查询文本
            collection_name: 集合名称
            top_k: 返回结果数量
            
        Returns:
            RAG查询结果列表
        """
        try:
            logger.info(f"在集合 {collection_name} 中查询: {query_text}")
            
            collection = self.collections.get(collection_name)
            if not collection:
                logger.error(f"集合 {collection_name} 不存在")
                return []
            
            # 生成查询向量
            query_embedding = await self._generate_embeddings([query_text])
            
            # 执行查询
            results = collection.query(
                query_embeddings=query_embedding,
                n_results=top_k,
                include=["documents", "metadatas", "distances"]
            )
            
            # 转换结果格式
            rag_results = []
            if results["documents"] and results["documents"][0]:
                for i in range(len(results["documents"][0])):
                    content = results["documents"][0][i]
                    metadata = results["metadatas"][0][i] if results["metadatas"] else {}
                    distance = results["distances"][0][i] if results["distances"] else 1.0
                    
                    # 将距离转换为相关性分数 (距离越小相关性越高)
                    relevance_score = max(0.0, 1.0 - distance)
                    
                    rag_results.append(RAGResult(
                        content=content,
                        source=metadata.get("source", "unknown"),
                        relevance_score=relevance_score
                    ))
            
            logger.info(f"查询完成，返回 {len(rag_results)} 个结果")
            return rag_results
            
        except Exception as e:
            logger.error(f"RAG查询失败: {e}")
            return []
    
    async def _generate_embeddings(self, texts: List[str]) -> List[List[float]]:
        """生成文本的embeddings"""
        try:
            # 使用langchain的OpenAI embeddings (同步方法)
            embeddings = []
            for text in texts:
                embedding = self.embeddings.embed_query(text)
                embeddings.append(embedding)
            return embeddings
        except Exception as e:
            logger.error(f"生成embeddings失败: {e}")
            # 返回随机向量作为fallback
            import random
            return [[random.random() for _ in range(1536)] for _ in texts]
    
    async def initialize_default_knowledge(self):
        """初始化默认知识库"""
        logger.info("初始化默认知识库")
        
        # 系统使用引导知识
        system_guide_docs = [
            {
                "content": "MES系统登录方式：1. 打开浏览器访问系统地址 2. 输入用户名和密码 3. 点击登录按钮",
                "metadata": {"source": "用户手册", "type": "login_guide"}
            },
            {
                "content": "物料管理功能：可以进行物料的入库、出库、盘点操作。入库流程：物料管理->入库管理->新增入库单",
                "metadata": {"source": "用户手册", "type": "material_management"}
            },
            {
                "content": "生产计划管理：制定和调整生产计划，查看生产进度。操作路径：生产管理->生产计划->新增计划",
                "metadata": {"source": "用户手册", "type": "production_planning"}
            }
        ]
        
        # 页面导航知识
        page_navigation_docs = [
            {
                "content": "入库操作页面路径：主菜单->物料管理->入库管理，点击'新增入库单'按钮",
                "metadata": {"source": "页面路径配置", "page": "/material/inbound"}
            },
            {
                "content": "出库操作页面路径：主菜单->物料管理->出库管理，点击'新增出库单'按钮", 
                "metadata": {"source": "页面路径配置", "page": "/material/outbound"}
            },
            {
                "content": "生产计划页面路径：主菜单->生产管理->生产计划，点击'新增计划'按钮",
                "metadata": {"source": "页面路径配置", "page": "/production/plan"}
            }
        ]
        
        # 生产数据知识
        production_data_docs = [
            {
                "content": "生产效率计算方式：实际产量/计划产量*100%。正常生产效率应维持在85%以上",
                "metadata": {"source": "生产标准", "type": "efficiency"}
            },
            {
                "content": "设备状态监控：可以实时查看设备运行状态、故障信息和维护记录",
                "metadata": {"source": "设备管理手册", "type": "equipment"}
            }
        ]
        
        # 添加到对应集合
        await self.add_documents(system_guide_docs, "system_guide")
        await self.add_documents(page_navigation_docs, "page_navigation")
        await self.add_documents(production_data_docs, "production_data")
        
        logger.info("默认知识库初始化完成") 