"""工具调用服务模块 - 基于Function Calling的多轮工具执行框架"""

import json
import os
from typing import Dict, Any, List, Optional, Callable, Union
from loguru import logger
import httpx
import asyncio
from datetime import datetime

from ..models.schemas import ToolCallResult


# ==================== 工具函数实现 ====================

def page_navigation(page_path: str, operation: str = "", **kwargs) -> Dict[str, Any]:
    """
    页面跳转工具
    
    Args:
        page_path: 目标页面路径
        operation: 操作描述
        
    Returns:
        跳转结果
    """
    logger.info(f"执行页面跳转: {operation} -> {page_path}")
    
    return {
        "action": "navigate",
        "page_path": page_path,
        "operation": operation,
        "timestamp": datetime.now().isoformat(),
        "success": True
    }


def database_query(query_type: str, table_name: str = "", filters: Dict[str, Any] = None, **kwargs) -> Dict[str, Any]:
    """
    数据库查询工具
    
    Args:
        query_type: 查询类型
        table_name: 表名
        filters: 过滤条件
        
    Returns:
        查询结果
    """
    logger.info(f"执行数据库查询: {query_type}")
    
    filters = filters or {}
    
    # 模拟数据库查询结果
    mock_data = {
        "production_status": {
            "total_orders": 150,
            "completed_orders": 128,
            "in_progress_orders": 18,
            "pending_orders": 4,
            "efficiency": 85.3,
            "daily_output": [
                {"date": "2024-01-15", "output": 1250, "target": 1300, "efficiency": 96.2},
                {"date": "2024-01-16", "output": 1180, "target": 1300, "efficiency": 90.8},
                {"date": "2024-01-17", "output": 1320, "target": 1300, "efficiency": 101.5}
            ]
        },
        "material_inventory": {
            "total_materials": 1250,
            "low_stock_materials": 12,
            "out_of_stock_materials": 2,
            "recent_movements": [
                {"material": "钢材A", "operation": "入库", "quantity": 100, "date": "2024-01-15"},
                {"material": "塑料B", "operation": "出库", "quantity": 50, "date": "2024-01-16"}
            ],
            "inventory_list": [
                {"material": "钢材A", "current_stock": 500, "unit": "kg", "min_stock": 100},
                {"material": "塑料B", "current_stock": 200, "unit": "kg", "min_stock": 50}
            ]
        },
        "equipment_status": {
            "total_equipment": 45,
            "running": 38,
            "maintenance": 5,
            "fault": 2,
            "fault_list": [
                {"equipment_id": "设备001", "fault": "传感器故障", "level": "中等", "reported_time": "2024-01-15 10:30"},
                {"equipment_id": "设备025", "fault": "电机异常", "level": "严重", "reported_time": "2024-01-16 14:20"}
            ],
            "equipment_list": [
                {"id": "设备001", "name": "注塑机1号", "status": "故障", "uptime": "95%"},
                {"id": "设备002", "name": "组装线A", "status": "运行", "uptime": "98%"}
            ]
        },
        "order_management": {
            "pending_orders": [
                {"order_id": "ORD001", "customer": "客户A", "quantity": 100, "due_date": "2024-02-01", "priority": "高"},
                {"order_id": "ORD002", "customer": "客户B", "quantity": 200, "due_date": "2024-02-05", "priority": "中"}
            ],
            "completed_orders": [
                {"order_id": "ORD100", "customer": "客户C", "quantity": 150, "completion_date": "2024-01-15", "quality": "优"}
            ]
        }
    }
    
    result = mock_data.get(query_type, {"message": "未找到相关数据"})
    
    # 应用过滤条件
    if filters and isinstance(result, dict):
        result["applied_filters"] = filters
        result["query_time"] = datetime.now().isoformat()
    
    return result


def report_generation(report_type: str, format: str = "excel", date_range: Dict[str, str] = None, **kwargs) -> Dict[str, Any]:
    """
    报表生成工具
    
    Args:
        report_type: 报表类型
        format: 输出格式 (excel/pdf/word)
        date_range: 日期范围
        
    Returns:
        报表生成结果
    """
    logger.info(f"生成报表: {report_type} ({format})")
    
    date_range = date_range or {"start": "2024-01-01", "end": "2024-01-31"}
    
    mock_reports = {
        "production_summary": {
            "report_name": "生产汇总报表",
            "period": f"{date_range.get('start')} 至 {date_range.get('end')}",
            "summary": {
                "total_production": 15240,
                "target_production": 16000,
                "efficiency": 95.25,
                "quality_rate": 98.5
            },
            "download_url": f"/reports/production_summary_{format}.{format}",
            "status": "生成完成",
            "file_size": "2.5MB"
        },
        "material_consumption": {
            "report_name": "物料消耗报表",
            "period": f"{date_range.get('start')} 至 {date_range.get('end')}",
            "top_consumed": [
                {"material": "钢材A", "consumed": 1250, "unit": "kg", "cost": 25000},
                {"material": "塑料B", "consumed": 850, "unit": "kg", "cost": 8500}
            ],
            "download_url": f"/reports/material_consumption_{format}.{format}",
            "status": "生成完成",
            "file_size": "1.8MB"
        },
        "quality_report": {
            "report_name": "质量检测报表",
            "period": f"{date_range.get('start')} 至 {date_range.get('end')}",
            "quality_metrics": {
                "pass_rate": 98.5,
                "defect_rate": 1.5,
                "rework_rate": 0.8
            },
            "download_url": f"/reports/quality_report_{format}.{format}",
            "status": "生成完成",
            "file_size": "3.2MB"
        }
    }
    
    return mock_reports.get(report_type, {"error": "不支持的报表类型", "supported_types": list(mock_reports.keys())})


def data_analysis(analysis_type: str, data_source: str, parameters: Dict[str, Any] = None, **kwargs) -> Dict[str, Any]:
    """
    数据分析工具
    
    Args:
        analysis_type: 分析类型
        data_source: 数据源
        parameters: 分析参数
        
    Returns:
        分析结果
    """
    logger.info(f"执行数据分析: {analysis_type} on {data_source}")
    
    parameters = parameters or {}
    
    mock_analyses = {
        "trend_analysis": {
            "analysis_name": "趋势分析",
            "data_source": data_source,
            "trend": "上升",
            "growth_rate": 15.5,
            "prediction": "预计下月将继续上升",
            "confidence": 0.85,
            "data_points": [
                {"period": "2024-01-01", "value": 100},
                {"period": "2024-01-15", "value": 115},
                {"period": "2024-01-31", "value": 130}
            ]
        },
        "efficiency_analysis": {
            "analysis_name": "效率分析",
            "data_source": data_source,
            "current_efficiency": 87.3,
            "baseline_efficiency": 85.0,
            "improvement": 2.3,
            "recommendations": ["优化设备维护计划", "提升员工技能培训", "调整生产排程"],
            "bottlenecks": ["设备001效率偏低", "物料供应不及时"]
        },
        "quality_analysis": {
            "analysis_name": "质量分析",
            "data_source": data_source,
            "defect_rate": 1.2,
            "improvement": -0.3,
            "main_issues": ["尺寸偏差", "表面缺陷"],
            "suggested_actions": ["调整设备参数", "加强质检", "优化工艺流程"],
            "quality_trends": [
                {"date": "2024-01-01", "defect_rate": 1.8},
                {"date": "2024-01-15", "defect_rate": 1.4},
                {"date": "2024-01-31", "defect_rate": 1.2}
            ]
        }
    }
    
    result = mock_analyses.get(analysis_type, {"error": "不支持的分析类型"})
    if "error" not in result:
        result["parameters"] = parameters
        result["analysis_time"] = datetime.now().isoformat()
    
    return result


def document_generation(template_type: str, data: Dict[str, Any], output_format: str = "docx", **kwargs) -> Dict[str, Any]:
    """
    文档生成工具
    
    Args:
        template_type: 模板类型
        data: 文档数据
        output_format: 输出格式
        
    Returns:
        文档生成结果
    """
    logger.info(f"生成文档: {template_type} ({output_format})")
    
    templates = {
        "work_order": {
            "template_name": "工单模板",
            "required_fields": ["order_id", "product_name", "quantity", "due_date"],
            "generated_file": f"work_order_{datetime.now().strftime('%Y%m%d_%H%M%S')}.{output_format}",
            "data_validation": "通过"
        },
        "inspection_report": {
            "template_name": "检验报告模板", 
            "required_fields": ["batch_id", "inspector", "inspection_date", "results"],
            "generated_file": f"inspection_report_{datetime.now().strftime('%Y%m%d_%H%M%S')}.{output_format}",
            "data_validation": "通过"
        },
        "maintenance_record": {
            "template_name": "维护记录模板",
            "required_fields": ["equipment_id", "maintenance_type", "technician", "completion_date"],
            "generated_file": f"maintenance_record_{datetime.now().strftime('%Y%m%d_%H%M%S')}.{output_format}",
            "data_validation": "通过"
        }
    }
    
    template_info = templates.get(template_type, {"error": "不支持的模板类型"})
    
    if "error" not in template_info:
        template_info["data"] = data
        template_info["status"] = "生成完成"
        template_info["download_url"] = f"/documents/{template_info['generated_file']}"
        
        # 验证必需字段
        required_fields = template_info.get("required_fields", [])
        missing_fields = [field for field in required_fields if field not in data]
        if missing_fields:
            template_info["data_validation"] = f"缺少必需字段: {', '.join(missing_fields)}"
    
    return template_info


def external_api_call(endpoint: str, method: str = "GET", headers: Dict[str, str] = None, payload: Dict[str, Any] = None, **kwargs) -> Dict[str, Any]:
    """
    外部API调用工具
    
    Args:
        endpoint: API端点
        method: HTTP方法
        headers: 请求头
        payload: 请求数据
        
    Returns:
        API调用结果
    """
    logger.info(f"调用外部API: {method} {endpoint}")
    
    # 模拟API调用结果
    mock_responses = {
        "/api/weather": {"temperature": 22, "humidity": 65, "condition": "晴"},
        "/api/system/status": {"status": "运行正常", "uptime": "99.9%", "last_restart": "2024-01-10"},
        "/api/erp/orders": {"orders": [{"id": "ORD001", "status": "已确认"}]},
        "/api/warehouse/inventory": {"materials": [{"name": "钢材A", "stock": 500}]}
    }
    
    response_data = mock_responses.get(endpoint, {"message": f"模拟API响应: {endpoint}"})
    
    return {
        "endpoint": endpoint,
        "method": method,
        "status_code": 200,
        "response": response_data,
        "timestamp": datetime.now().isoformat(),
        "headers": headers or {},
        "payload": payload or {}
    }


def rag_search(query: str, collection: str = "default", top_k: int = 5, **kwargs) -> Dict[str, Any]:
    """
    RAG搜索工具 - 在工具调用中使用RAG功能
    
    Args:
        query: 搜索查询
        collection: 知识库集合
        top_k: 返回结果数量
        
    Returns:
        搜索结果
    """
    logger.info(f"执行RAG搜索: {query} in {collection}")
    
    # 模拟RAG搜索结果
    mock_results = {
        "query": query,
        "collection": collection,
        "results": [
            {
                "content": f"相关文档内容1：关于 {query} 的详细说明，包括操作步骤和注意事项...",
                "source": "用户手册第3章",
                "relevance_score": 0.95
            },
            {
                "content": f"相关文档内容2：{query} 的最佳实践和常见问题解决方案...",
                "source": "操作指南",
                "relevance_score": 0.88
            },
            {
                "content": f"相关文档内容3：{query} 相关的系统配置和参数设置...",
                "source": "技术文档",
                "relevance_score": 0.82
            }
        ],
        "total_results": top_k,
        "search_time": datetime.now().isoformat()
    }
    
    return mock_results


def workflow_execution(workflow_name: str, input_data: Dict[str, Any] = None, **kwargs) -> Dict[str, Any]:
    """
    工作流执行工具
    
    Args:
        workflow_name: 工作流名称
        input_data: 输入数据
        
    Returns:
        工作流执行结果
    """
    logger.info(f"执行工作流: {workflow_name}")
    
    input_data = input_data or {}
    
    workflows = {
        "material_procurement": {
            "workflow_name": "物料采购流程",
            "steps": [
                {"step": "需求分析", "status": "完成"},
                {"step": "供应商选择", "status": "进行中"},
                {"step": "采购审批", "status": "待执行"},
                {"step": "订单下达", "status": "待执行"}
            ],
            "current_step": 2,
            "estimated_completion": "2024-02-01"
        },
        "quality_inspection": {
            "workflow_name": "质量检验流程",
            "steps": [
                {"step": "样品抽取", "status": "完成"},
                {"step": "检验测试", "status": "完成"},
                {"step": "数据分析", "status": "完成"},
                {"step": "报告生成", "status": "完成"}
            ],
            "current_step": 4,
            "result": "合格",
            "completion_time": datetime.now().isoformat()
        }
    }
    
    result = workflows.get(workflow_name, {"error": "不支持的工作流类型"})
    if "error" not in result:
        result["input_data"] = input_data
        result["execution_id"] = f"WF_{datetime.now().strftime('%Y%m%d_%H%M%S')}"
    
    return result


# ==================== 工具函数映射表 ====================

FUNCTION_MAP = {
    "page_navigation": page_navigation,
    "database_query": database_query,
    "report_generation": report_generation,
    "data_analysis": data_analysis,
    "document_generation": document_generation,
    "external_api_call": external_api_call,
    "rag_search": rag_search,
    "workflow_execution": workflow_execution,
}


# ==================== 工具执行器 ====================

def execute_tool_function(function_name: str, **kwargs) -> Any:
    """
    执行指定的工具函数
    
    Args:
        function_name: 函数名
        **kwargs: 函数参数
        
    Returns:
        函数执行结果
    """
    if function_name not in FUNCTION_MAP:
        return {"error": f"未知的工具函数: {function_name}"}
    
    try:
        return FUNCTION_MAP[function_name](**kwargs)
    except Exception as e:
        logger.error(f"执行工具函数 {function_name} 时出错: {e}")
        return {"error": f"执行工具函数 {function_name} 时出错: {str(e)}"}


# ==================== 工具服务类 ====================

class ToolService:
    """工具服务管理类 - 支持多轮Function Calling"""
    
    def __init__(self, openai_client=None, rag_service=None):
        self.openai_client = openai_client
        self.rag_service = rag_service
        self.function_map = FUNCTION_MAP
        
        logger.info(f"工具服务初始化完成，注册了 {len(self.function_map)} 个工具")
    
    def get_available_tools(self) -> List[str]:
        """获取可用工具列表"""
        return list(self.function_map.keys())
    
    def get_tool_schemas(self) -> List[Dict[str, Any]]:
        """获取工具Schema列表"""
        # 从配置文件读取schema
        try:
            schema_file = os.path.join(os.path.dirname(__file__), "tool_schemas.json")
            with open(schema_file, 'r', encoding='utf-8') as f:
                return json.load(f)
        except FileNotFoundError:
            logger.warning("未找到tool_schemas.json，使用默认schema")
            return self._get_default_schemas()
    
    def _get_default_schemas(self) -> List[Dict[str, Any]]:
        """获取默认工具Schema"""
        return [
            {
                "name": "page_navigation",
                "description": "页面跳转工具，用于导航到MES系统的不同页面",
                "parameters": {
                    "type": "object",
                    "properties": {
                        "page_path": {"type": "string", "description": "目标页面路径"},
                        "operation": {"type": "string", "description": "操作描述"}
                    },
                    "required": ["page_path"]
                }
            },
            {
                "name": "database_query",
                "description": "数据库查询工具，用于查询生产、物料、设备等数据",
                "parameters": {
                    "type": "object",
                    "properties": {
                        "query_type": {
                            "type": "string",
                            "enum": ["production_status", "material_inventory", "equipment_status", "order_management"]
                        },
                        "table_name": {"type": "string"},
                        "filters": {"type": "object"}
                    },
                    "required": ["query_type"]
                }
            }
        ]
    
    async def execute_tool(self, tool_name: str, params: Dict[str, Any]) -> ToolCallResult:
        """执行单个工具调用"""
        try:
            logger.info(f"执行工具: {tool_name}")
            
            # 特殊处理RAG搜索工具
            if tool_name == "rag_search" and self.rag_service:
                query = params.get("query", "")
                collection = params.get("collection", "system_guide")
                top_k = params.get("top_k", 5)
                
                rag_results = await self.rag_service.query(query, collection, top_k)
                result = {
                    "query": query,
                    "collection": collection,
                    "results": [
                        {
                            "content": r.content,
                            "source": r.source,
                            "relevance_score": r.relevance_score
                        }
                        for r in rag_results
                    ],
                    "total_results": len(rag_results)
                }
            else:
                # 执行其他工具
                result = execute_tool_function(tool_name, **params)
            
            return ToolCallResult(
                tool_name=tool_name,
                result=result,
                success=True
            )
            
        except Exception as e:
            logger.error(f"工具执行失败 {tool_name}: {e}")
            return ToolCallResult(
                tool_name=tool_name,
                result=None,
                success=False,
                error_message=str(e)
            )
    
    async def execute_multi_turn_tool_calls(
        self, 
        initial_prompt: str, 
        context: Dict[str, Any] = None,
        max_turns: int = 10
    ) -> List[ToolCallResult]:
        """
        执行多轮工具调用，参考report_generation.py的实现模式
        
        Args:
            initial_prompt: 初始任务描述
            context: 上下文信息
            max_turns: 最大轮次
            
        Returns:
            所有工具调用结果
        """
        if not self.openai_client:
            logger.error("未配置OpenAI客户端，无法执行多轮工具调用")
            return []
        
        logger.info(f"开始多轮工具调用: {initial_prompt}")
        
        tool_results = []
        
        # 构建增强的用户提示词，包含多轮调用指令
        enhanced_prompt = f"""{initial_prompt}

你可以使用提供的工具来完成这个任务。你可以进行多轮操作实现你的目标，如执行完操作后还有后续操作，请回复：'尚未完成'，如执行完成，请回复'已完成'。

可用工具说明：
- page_navigation: 页面跳转导航
- database_query: 查询生产数据、设备状态等
- report_generation: 生成各类报表
- data_analysis: 数据分析和趋势预测
- document_generation: 生成业务文档
- external_api_call: 调用外部API
- rag_search: 搜索知识库
- workflow_execution: 执行工作流程

请根据任务需求选择合适的工具，按步骤完成任务。"""

        # 添加上下文信息
        if context:
            context_str = f"\n\n上下文信息：{json.dumps(context, ensure_ascii=False, indent=2)}"
            enhanced_prompt += context_str
        
        messages = [
            {"role": "user", "content": enhanced_prompt}
        ]
        
        # 获取工具schema
        functions = self.get_tool_schemas()
        
        # 首次调用
        try:
            response = self.openai_client.chat.completions.create(
                model="gpt-3.5-turbo",
                messages=messages,
                functions=functions,
                function_call="auto",
                temperature=0.1
            )
            
            message = response.choices[0].message
            logger.info(f"首次响应: {message.content}")
            
            messages.append({
                "role": "assistant",
                "content": message.content,
                "function_call": message.function_call
            })
            
            # 多轮调用循环
            turn = 0
            while turn < max_turns:
                turn += 1
                
                # 检查是否完成
                if message.content and "已完成" in message.content:
                    logger.info("任务完成")
                    break
                
                # 执行工具调用
                if message.function_call:
                    function_name = message.function_call.name
                    try:
                        function_args = json.loads(message.function_call.arguments)
                    except json.JSONDecodeError as e:
                        logger.error(f"解析函数参数失败: {e}")
                        function_args = {}
                    
                    # 执行工具
                    tool_result = await self.execute_tool(function_name, function_args)
                    tool_results.append(tool_result)
                    
                    # 准备结果内容
                    if tool_result.success:
                        result_content = json.dumps(tool_result.result, ensure_ascii=False) if tool_result.result else "执行成功"
                    else:
                        result_content = tool_result.error_message or "执行失败"
                    
                    # 添加工具执行结果到消息历史
                    messages.append({
                        "role": "function",
                        "name": function_name,
                        "content": result_content
                    })
                    
                    logger.info(f"第{turn}轮 - 工具 {function_name} 执行{'成功' if tool_result.success else '失败'}")
                    
                    # 继续下一轮调用
                    response = self.openai_client.chat.completions.create(
                        model="gpt-3.5-turbo",
                        messages=messages,
                        functions=functions,
                        function_call="auto",
                        temperature=0.1
                    )
                    
                    message = response.choices[0].message
                    logger.info(f"第{turn}轮响应: {message.content}")
                    
                    messages.append({
                        "role": "assistant",
                        "content": message.content,
                        "function_call": message.function_call
                    })
                    
                else:
                    # 没有function call但也没完成，询问并尝试继续
                    logger.warning(f"第{turn}轮 - 没有工具调用但任务未完成")
                    messages.append({
                        "role": "user",
                        "content": "你回复了尚未完成，但并没有返回function call，是遇到什么问题了吗？如果需要继续执行，请继续回复：尚未完成"
                    })
                    
                    response = self.openai_client.chat.completions.create(
                        model="gpt-3.5-turbo",
                        messages=messages,
                        functions=functions,
                        function_call="auto",
                        temperature=0.1
                    )
                    
                    message = response.choices[0].message
                    messages.append({
                        "role": "assistant",
                        "content": message.content,
                        "function_call": message.function_call
                    })
            
            if turn >= max_turns:
                logger.warning(f"达到最大轮次限制({max_turns})，停止执行")
                
        except Exception as e:
            logger.error(f"多轮工具调用执行失败: {e}")
            return []
        
        logger.info(f"多轮工具调用完成，共执行了 {len(tool_results)} 个工具")
        return tool_results
    
    async def batch_execute_tools(self, tool_calls: List[Dict[str, Any]]) -> List[ToolCallResult]:
        """批量执行工具调用"""
        results = []
        
        for tool_call in tool_calls:
            tool_name = tool_call.get("tool_name", "")
            params = tool_call.get("params", {})
            
            result = await self.execute_tool(tool_name, params)
            results.append(result)
        
        return results
    
    def register_custom_tool(self, name: str, function: Callable, schema: Dict[str, Any]):
        """注册自定义工具"""
        self.function_map[name] = function
        logger.info(f"注册自定义工具: {name}")
    
    def get_tool_function(self, name: str) -> Optional[Callable]:
        """获取工具函数"""
        return self.function_map.get(name) 