"""配置管理模块"""

import os
from typing import Dict, Any, Optional
from pydantic import Field
from pydantic_settings import BaseSettings
from dotenv import load_dotenv

# 加载环境变量
load_dotenv()


class Settings(BaseSettings):
    """应用配置类"""
    
    # 基础配置
    app_name: str = Field("MES AI Service", description="应用名称")
    app_version: str = Field("0.1.0", description="应用版本")
    debug: bool = Field(False, description="调试模式")
    
    # 服务器配置
    host: str = Field("0.0.0.0", description="服务器主机")
    port: int = Field(8000, description="服务器端口")
    workers: int = Field(1, description="工作进程数")
    
    # OpenAI配置
    openai_api_key: str = Field(..., description="OpenAI API密钥")
    openai_model: str = Field("gpt-3.5-turbo", description="OpenAI模型")
    openai_max_tokens: int = Field(1000, description="最大token数")
    openai_temperature: float = Field(0.7, description="温度参数")
    
    # 数据库配置
    database_url: Optional[str] = Field(None, description="数据库连接URL")
    database_host: str = Field("localhost", description="数据库主机")
    database_port: int = Field(3306, description="数据库端口")
    database_user: str = Field("mes_user", description="数据库用户")
    database_password: str = Field("", description="数据库密码")
    database_name: str = Field("mes_db", description="数据库名称")
    
    # Redis配置
    redis_url: Optional[str] = Field(None, description="Redis连接URL")
    redis_host: str = Field("localhost", description="Redis主机")
    redis_port: int = Field(6379, description="Redis端口")
    redis_password: Optional[str] = Field(None, description="Redis密码")
    redis_db: int = Field(0, description="Redis数据库")
    
    # 知识库配置
    knowledge_base_path: str = Field("knowledge_base", description="知识库路径")
    vector_db_path: str = Field("knowledge_base/chroma_db", description="向量数据库路径")
    
    # 日志配置
    log_level: str = Field("INFO", description="日志级别")
    log_file: Optional[str] = Field(None, description="日志文件路径")
    log_rotation: str = Field("100 MB", description="日志轮转大小")
    log_retention: str = Field("30 days", description="日志保留时间")
    
    # 安全配置
    secret_key: str = Field("your-secret-key-here", description="应用密钥")
    cors_origins: list = Field(["*"], description="CORS允许的源")
    
    # API配置
    api_prefix: str = Field("/api/v1", description="API前缀")
    api_rate_limit: str = Field("100/minute", description="API限流")
    
    # 外部API配置
    external_api_timeout: int = Field(30, description="外部API超时时间")
    external_api_retries: int = Field(3, description="外部API重试次数")
    
    class Config:
        env_prefix = "MES_AI_"
        case_sensitive = False
        env_file = ".env"
        env_file_encoding = "utf-8"


# 全局配置实例
settings = Settings()


def get_database_config() -> Dict[str, Any]:
    """获取数据库配置"""
    if settings.database_url:
        return {"url": settings.database_url}
    
    return {
        "host": settings.database_host,
        "port": settings.database_port,
        "user": settings.database_user,
        "password": settings.database_password,
        "database": settings.database_name,
    }


def get_redis_config() -> Dict[str, Any]:
    """获取Redis配置"""
    if settings.redis_url:
        return {"url": settings.redis_url}
    
    config = {
        "host": settings.redis_host,
        "port": settings.redis_port,
        "db": settings.redis_db,
    }
    
    if settings.redis_password:
        config["password"] = settings.redis_password
    
    return config


def get_openai_config() -> Dict[str, Any]:
    """获取OpenAI配置"""
    return {
        "api_key": settings.openai_api_key,
        "model": settings.openai_model,
        "max_tokens": settings.openai_max_tokens,
        "temperature": settings.openai_temperature,
    }


def get_external_api_config() -> Dict[str, Any]:
    """获取外部API配置"""
    return {
        "timeout": settings.external_api_timeout,
        "retries": settings.external_api_retries,
    } 