#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
提示词加载工具模块
负责从markdown文件中加载专家Agent的系统提示词
"""

import os
from typing import Dict, Optional
from loguru import logger


class PromptLoader:
    """提示词加载器"""
    
    def __init__(self, prompts_dir: str = "prompts"):
        """
        初始化提示词加载器
        
        Args:
            prompts_dir: 提示词文件根目录
        """
        self.prompts_dir = prompts_dir
        self.expert_agents_dir = os.path.join(prompts_dir, "expert_agents")
        self._prompt_cache: Dict[str, str] = {}
        
    def load_expert_prompt(self, agent_name: str) -> str:
        """
        加载专家Agent的系统提示词
        
        Args:
            agent_name: Agent名称 (如: 'page_navigation_agent')
            
        Returns:
            系统提示词字符串
        """
        # 检查缓存
        if agent_name in self._prompt_cache:
            return self._prompt_cache[agent_name]
        
        # 构建文件路径
        prompt_file = os.path.join(self.expert_agents_dir, f"{agent_name}.md")
        
        try:
            # 读取提示词文件
            if os.path.exists(prompt_file):
                with open(prompt_file, 'r', encoding='utf-8') as f:
                    prompt_content = f.read().strip()
                
                # 缓存提示词
                self._prompt_cache[agent_name] = prompt_content
                logger.info(f"成功加载专家Agent提示词: {agent_name}")
                return prompt_content
            else:
                logger.warning(f"提示词文件不存在: {prompt_file}")
                return self._get_default_prompt(agent_name)
                
        except Exception as e:
            logger.error(f"加载提示词失败 {agent_name}: {e}")
            return self._get_default_prompt(agent_name)
    
    def _get_default_prompt(self, agent_name: str) -> str:
        """
        获取默认的系统提示词
        
        Args:
            agent_name: Agent名称
            
        Returns:
            默认提示词
        """
        default_prompts = {
            'page_navigation_agent': """
你是MES系统的页面跳转引导专家，负责帮助用户快速导航到目标功能页面。
你具备深厚的MES系统架构知识，能够准确识别用户需求并提供最优的页面跳转方案。
请为用户提供清晰、准确的页面导航指引。
            """.strip(),
            
            'system_guide_agent': """
你是MES系统的使用指导专家，拥有丰富的系统操作经验和教学能力。
你的使命是帮助用户快速掌握系统功能，提高工作效率，并确保操作的正确性。
请为用户提供详细、实用的操作指导和最佳实践建议。
            """.strip(),
            
            'production_qa_agent': """
你是MES系统的生产数据查询分析专家，具备深厚的制造业背景知识和数据分析能力。
你能够准确理解用户的数据需求，高效执行数据查询，并提供有价值的分析洞察。
请为用户提供准确的数据查询和深入的分析见解。
            """.strip(),
            
            'chat_agent': """
你是MES系统的智能对话助手，具备丰富的系统知识和优秀的沟通能力。
你的使命是为用户提供友好、专业、有价值的对话体验，同时引导用户充分利用MES系统功能。
请保持友好专业的对话氛围，并主动引导用户发现系统价值。
            """.strip()
        }
        
        return default_prompts.get(agent_name, "你是一个专业的MES系统AI助手，请为用户提供专业的帮助。")
    
    def reload_prompt(self, agent_name: str) -> str:
        """
        重新加载指定Agent的提示词（清除缓存后重新读取）
        
        Args:
            agent_name: Agent名称
            
        Returns:
            重新加载的提示词
        """
        # 清除缓存
        if agent_name in self._prompt_cache:
            del self._prompt_cache[agent_name]
        
        # 重新加载
        return self.load_expert_prompt(agent_name)
    
    def get_all_agent_names(self) -> list:
        """
        获取所有可用的Agent名称
        
        Returns:
            Agent名称列表
        """
        agent_names = []
        
        if os.path.exists(self.expert_agents_dir):
            for filename in os.listdir(self.expert_agents_dir):
                if filename.endswith('.md'):
                    agent_name = filename[:-3]  # 移除.md扩展名
                    agent_names.append(agent_name)
        
        return agent_names
    
    def validate_prompts(self) -> Dict[str, bool]:
        """
        验证所有提示词文件的可用性
        
        Returns:
            验证结果字典 {agent_name: is_valid}
        """
        validation_results = {}
        
        expected_agents = [
            'page_navigation_agent',
            'system_guide_agent', 
            'production_qa_agent',
            'chat_agent'
        ]
        
        for agent_name in expected_agents:
            prompt_file = os.path.join(self.expert_agents_dir, f"{agent_name}.md")
            is_valid = os.path.exists(prompt_file) and os.path.getsize(prompt_file) > 0
            validation_results[agent_name] = is_valid
            
            if not is_valid:
                logger.warning(f"提示词文件无效或不存在: {prompt_file}")
        
        return validation_results


# 全局提示词加载器实例
_prompt_loader: Optional[PromptLoader] = None


def get_prompt_loader() -> PromptLoader:
    """
    获取全局提示词加载器实例
    
    Returns:
        PromptLoader实例
    """
    global _prompt_loader
    
    if _prompt_loader is None:
        _prompt_loader = PromptLoader()
    
    return _prompt_loader


def load_expert_prompt(agent_name: str) -> str:
    """
    便捷函数：加载专家Agent提示词
    
    Args:
        agent_name: Agent名称
        
    Returns:
        系统提示词
    """
    return get_prompt_loader().load_expert_prompt(agent_name) 